import datetime
from application import db
from application.models.users import *
from application.models.applications import Application, Skill, ReviewersApplications

from flask import render_template, redirect, url_for, request, Blueprint
from flask.ext.security import login_required, roles_accepted
from flask.ext.security.core import current_user
from flask_wtf import Form
from wtforms import TextField, TextAreaField, BooleanField, SelectMultipleField
from wtforms.validators import DataRequired
from wtforms.fields.html5 import URLField
from wtforms.validators import url

applications = Blueprint('applications', __name__)

@applications.route('/')
@roles_accepted('bfct_manager', 'admin')
def index():
    return render_template('applications/index.html', 
        title='applications',
        applications=Application.query.all())

@applications.route('/view/<int:id>')
@roles_accepted('bfct_manager', 'admin')
def view(id):
    review = ReviewersApplications.query.\
        filter_by(application_id=id).\
        filter_by(reviewer_blender_id=current_user.id).\
        first()

    reviews = ReviewersApplications.query.\
        filter_by(application_id=id).\
        all()

    return render_template('applications/view.html', 
        title='applications',
        application=Application.query.get_or_404(id),
        review=review,
        reviews=reviews)

@applications.route('/vote/<int:approved>/<int:id>')
@roles_accepted('bfct_manager', 'admin')
def vote(approved, id):
    application = Application.query.get_or_404(id)
    review = ReviewersApplications.query.\
        filter_by(application_id=id).\
        filter_by(reviewer_blender_id=current_user.id).\
        first()

    if approved:
        if review:
            application.reject -= 1
        application.approve += 1
    else:
        if review:
            application.approve -= 1
        application.reject += 1

    if application.status == 'submitted':
        application.status = 'under_review'
        application.review_start_date = datetime.datetime.now()
    db.session.add(application)

    if not review:
        review = ReviewersApplications(
            application_id=id,
            reviewer_blender_id=current_user.id,
            approved=approved) 
    else:
        review.approved = approved

    db.session.add(review)
    
    db.session.commit()
    return redirect(url_for('.view', id=id))

@applications.route('/final-review/<int:approved>/<int:id>')
@roles_accepted('admin')
def final_review(approved, id):
    application = Application.query.get_or_404(id)

    if application.status != 'under_review':
        return 'error'
    else:
        if approved:
            application.status = 'approved'
        else:
            application.status = 'rejected'
        application.review_end_date = datetime.datetime.now()
    db.session.add(application)
   
    db.session.commit()
    return redirect(url_for('.view', id=id))
