import datetime
from application import app
from application import db
from application.helpers import pretty_date
from users import User

from sqlalchemy.ext.associationproxy import association_proxy


class Application(db.Model):
    __table_args__ = {'schema': 'blender-bfct'}
    id = db.Column(db.Integer(), primary_key=True)
    blender_id = db.Column(db.Integer(), db.ForeignKey(User.id), nullable=False)
    user = db.relationship('User')
    network_profile = db.Column(db.String(255))
    website = db.Column(db.String(255))
    city_country = db.Column(db.String(255))
    institution_name = db.Column(db.String(255))
    skills = db.relationship('Skill', secondary='skills_applications',
                            backref=db.backref('applications', lazy='dynamic'))
    video_example = db.Column(db.String(255))
    written_example = db.Column(db.String(255))
    portfolio_cv = db.Column(db.String(255))
    bio_message = db.Column(db.Text())
    submission_date = db.Column(db.DateTime(), default=datetime.datetime.now)
    status = db.Column(db.String(255))
    approve = db.Column(db.Integer(), default=0)
    reject = db.Column(db.Integer(), default=0)
    review_start_date = db.Column(db.DateTime())
    review_end_date = db.Column(db.DateTime())
    renewal_date = db.Column(db.DateTime())

    def show_pretty_date(self, stage_date):
        if stage_date == 'submission':
            return pretty_date(self.submission_date)
        elif stage_date == 'review_start':
            return pretty_date(self.review_start_date)
        elif stage_date == 'review_end':
            return pretty_date(self.review_end_date)
        else:
            return '--'



class Skill(db.Model):
    id = db.Column(db.Integer(), primary_key=True)
    name = db.Column(db.String(80), unique=True)
    description = db.Column(db.String(255))
    
    def __str__(self):
        return self.name



skills_applications = db.Table('skills_applications',
        db.Column('application_id', db.Integer(), db.ForeignKey(Application.id)),
        db.Column('skill_id', db.Integer(), db.ForeignKey('skill.id')))


class ReviewersApplications(db.Model):
    id = db.Column(db.Integer(), primary_key=True)
    application_id = db.Column(db.Integer(), db.ForeignKey(Application.id), nullable=False)
    application = db.relationship('Application')
    reviewer_blender_id = db.Column(db.Integer(), db.ForeignKey(User.id), nullable=False)
    reviewer = db.relationship('User')
    approved = db.Column(db.Boolean(), nullable=False)
